# Table of Contents

- [using-mcp-server-for-tech-stack-management](<./using-mcp-server-for-tech-stack-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Using the MCP Server for Tech Stack Management](<./Using-the-MCP-Server-for-Tech-Stack-Management.md>)
  - [Overview](<./Using-the-MCP-Server-for-Tech-Stack-Management/Overview.md>)
  - [Benefits](<./Using-the-MCP-Server-for-Tech-Stack-Management/Benefits.md>)
  - [Permissions](<./Using-the-MCP-Server-for-Tech-Stack-Management/Permissions.md>)
  - [Example Use Cases](<./Using-the-MCP-Server-for-Tech-Stack-Management/Example-Use-Cases.md>)
